/* -- theme ------------------------------------------------------------ */

:root {
    /* colors from from https://github.com/jupyter/jupyter.github.io/blob/master/_sass/settings/_colors.scss */
    --color-dark-orange: 197, 84, 11;
    --color-dark-grey: 77, 77, 77;
    --pst-color-link: var(--color-dark-orange);

    --pst-color-h1: var(--color-dark-grey);
    --pst-color-h2: var(--color-dark-grey);
    --pst-color-h3: var(--color-dark-grey);
    --pst-color-h4: var(--color-dark-grey);
    --pst-color-h5: var(--color-dark-grey);
    --pst-color-h6: var(--color-dark-grey);

    --pst-color-active-navigation: var(--color-dark-orange);
}

/* -- navbar ------------------------------------------------------------- */

.navbar-brand {
    padding: 0.4em;
}

/* -- topics ------------------------------------------------------------- */

div.topic {
    border: 0px solid #ccc;
    padding: 7px 7px 0 7px;
    margin: 10px 0 10px 0;
}

p.topic-title {
    font-size: 1.1em;
    font-weight: bold;
    margin-top: 10px;
}

.alert {
    color: #222222;
}

p.first.admonition-title {
	color: #ffffff;
}


/* Front page table styling */

.front-page-table td > p {
    margin-bottom: 0em;
}

.front-page-table td > p:last-child {
    font-style: italic;
}

.front-page-table a.reference {
    font-size: 1.3em;
}

.front-page-table.table td, .front-page-table.table th {
    border: none;
    padding-top: .3em;
    padding-bottom: .3em;
}

div.card ul.simple {
    list-style: none;
    padding-left: 1em;
}
